# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_compute_virtualmachines.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3azure/azure_microsoft_compute_virtualmachines.proto\x12\x33oak9.tython.azure.microsoft_compute_virtualmachines\x1a\x13shared/shared.proto\"\xb0\x03\n\x19VirtualMachinesExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12r\n\nproperties\x18\x04 \x03(\x0b\x32^.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinesExtensions.PropertiesEntry\x12\x66\n\x04tags\x18\x05 \x03(\x0b\x32X.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinesExtensions.TagsEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1d\n\x0f\x41vailabilitySet\x12\n\n\x02id\x18\x01 \x01(\t\"\x83\x01\n!Microsoft_Compute_VirtualMachines\x12^\n\x10virtual_machines\x18\x01 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachines\"\xda\x05\n\x1aVirtualMachinesRunCommands\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0f\x61sync_execution\x18\x04 \x01(\x08\x12\x16\n\x0e\x65rror_blob_uri\x18\x05 \x01(\t\x12\x17\n\x0foutput_blob_uri\x18\x06 \x01(\t\x12\x61\n\nparameters\x18\x07 \x03(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachines.RunCommandInputParameter\x12k\n\x14protected_parameters\x18\x08 \x03(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachines.RunCommandInputParameter\x12\x17\n\x0frun_as_password\x18\t \x01(\t\x12\x13\n\x0brun_as_user\x18\n \x01(\t\x12i\n\x06source\x18\x0b \x01(\x0b\x32Y.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineRunCommandScriptSource\x12\x1a\n\x12timeout_in_seconds\x18\x0c \x01(\x05\x12g\n\x04tags\x18\r \x03(\x0b\x32Y.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinesRunCommands.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$VirtualMachineRunCommandScriptSource\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12\x0e\n\x06script\x18\x02 \x01(\t\x12\x12\n\nscript_uri\x18\x03 \x01(\t\"7\n\x18RunCommandInputParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9c\x11\n\x0fVirtualMachines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachines.ExtendedLocation\x12]\n\x08identity\x18\x03 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12G\n\x04plan\x18\x06 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_compute_virtualmachines.Plan\x12l\n\x17\x61\x64\x64itional_capabilities\x18\x07 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachines.AdditionalCapabilities\x12\x64\n\x13\x61pplication_profile\x18\x08 \x01(\x0b\x32G.oak9.tython.azure.microsoft_compute_virtualmachines.ApplicationProfile\x12\\\n\x0f\x62illing_profile\x18\t \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_compute_virtualmachines.BillingProfile\x12m\n\x14\x63\x61pacity_reservation\x18\n \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachines.CapacityReservationProfile\x12\x64\n\x13\x64iagnostics_profile\x18\x0b \x01(\x0b\x32G.oak9.tython.azure.microsoft_compute_virtualmachines.DiagnosticsProfile\x12\x17\n\x0f\x65viction_policy\x18\x0c \x01(\t\x12\x1e\n\x16\x65xtensions_time_budget\x18\r \x01(\t\x12^\n\x10hardware_profile\x18\x0e \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.HardwareProfile\x12\x0c\n\x04host\x18\x0f \x01(\t\x12\x12\n\nhost_group\x18\x10 \x01(\t\x12\x14\n\x0clicense_type\x18\x11 \x01(\t\x12\\\n\x0fnetwork_profile\x18\x12 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_compute_virtualmachines.NetworkProfile\x12R\n\nos_profile\x18\x13 \x01(\x0b\x32>.oak9.tython.azure.microsoft_compute_virtualmachines.OSProfile\x12\x1d\n\x15platform_fault_domain\x18\x14 \x01(\x05\x12\x10\n\x08priority\x18\x15 \x01(\t\x12!\n\x19proximity_placement_group\x18\x16 \x01(\t\x12m\n\x18scheduled_events_profile\x18\x17 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachines.ScheduledEventsProfile\x12^\n\x10security_profile\x18\x18 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.SecurityProfile\x12\\\n\x0fstorage_profile\x18\x19 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_compute_virtualmachines.StorageProfile\x12\x11\n\tuser_data\x18\x1a \x01(\t\x12!\n\x19virtual_machine_scale_set\x18\x1b \x01(\t\x12\\\n\x04tags\x18\x1c \x03(\x0b\x32N.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachines.TagsEntry\x12\r\n\x05zones\x18\x1d \x03(\t\x12s\n\x1bvirtual_machines_extensions\x18\x1e \x03(\x0b\x32N.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinesExtensions\x12v\n\x1dvirtual_machines_run_commands\x18\x1f \x03(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinesRunCommands\x12^\n\x10\x61vailability_set\x18  \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.AvailabilitySet\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x02\n\x0eStorageProfile\x12Q\n\ndata_disks\x18\x01 \x03(\x0b\x32=.oak9.tython.azure.microsoft_compute_virtualmachines.DataDisk\x12\\\n\x0fimage_reference\x18\x02 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_compute_virtualmachines.ImageReference\x12L\n\x07os_disk\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_compute_virtualmachines.OSDisk\"\xf6\x04\n\x06OSDisk\x12\x0f\n\x07\x63\x61\x63hing\x18\x01 \x01(\t\x12\x15\n\rcreate_option\x18\x02 \x01(\t\x12\x15\n\rdelete_option\x18\x03 \x01(\t\x12\x61\n\x12\x64iff_disk_settings\x18\x04 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachines.DiffDiskSettings\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x05\x12h\n\x13\x65ncryption_settings\x18\x06 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachines.DiskEncryptionSettings\x12S\n\x05image\x18\x07 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualHardDisk\x12`\n\x0cmanaged_disk\x18\x08 \x01(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachines.ManagedDiskParameters\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07os_type\x18\n \x01(\t\x12Q\n\x03vhd\x18\x0b \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualHardDisk\x12!\n\x19write_accelerator_enabled\x18\x0c \x01(\x08\"\xfb\x01\n\x16\x44iskEncryptionSettings\x12i\n\x13\x64isk_encryption_key\x18\x01 \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachines.KeyVaultSecretReference\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x65\n\x12key_encryption_key\x18\x03 \x01(\x0b\x32I.oak9.tython.azure.microsoft_compute_virtualmachines.KeyVaultKeyReference\"=\n\x14KeyVaultKeyReference\x12\x0f\n\x07key_url\x18\x01 \x01(\t\x12\x14\n\x0csource_vault\x18\x02 \x01(\t\"C\n\x17KeyVaultSecretReference\x12\x12\n\nsecret_url\x18\x01 \x01(\t\x12\x14\n\x0csource_vault\x18\x02 \x01(\t\"5\n\x10\x44iffDiskSettings\x12\x0e\n\x06option\x18\x01 \x01(\t\x12\x11\n\tplacement\x18\x02 \x01(\t\"\xa1\x01\n\x0eImageReference\x12\"\n\x1a\x63ommunity_gallery_image_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05offer\x18\x03 \x01(\t\x12\x11\n\tpublisher\x18\x04 \x01(\t\x12\x1f\n\x17shared_gallery_image_id\x18\x05 \x01(\t\x12\x0b\n\x03sku\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\"\xd6\x03\n\x08\x44\x61taDisk\x12\x0f\n\x07\x63\x61\x63hing\x18\x01 \x01(\t\x12\x15\n\rcreate_option\x18\x02 \x01(\t\x12\x15\n\rdelete_option\x18\x03 \x01(\t\x12\x15\n\rdetach_option\x18\x04 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x05\x12S\n\x05image\x18\x06 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualHardDisk\x12\x0b\n\x03lun\x18\x07 \x01(\x05\x12`\n\x0cmanaged_disk\x18\x08 \x01(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachines.ManagedDiskParameters\x12\x0c\n\x04name\x18\t \x01(\t\x12\x16\n\x0eto_be_detached\x18\n \x01(\x08\x12Q\n\x03vhd\x18\x0b \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualHardDisk\x12!\n\x19write_accelerator_enabled\x18\x0c \x01(\x08\"\x96\x02\n\x15ManagedDiskParameters\x12m\n\x13\x64isk_encryption_set\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_compute_virtualmachines.DiskEncryptionSetParameters\x12\n\n\x02id\x18\x02 \x01(\t\x12\x64\n\x10security_profile\x18\x03 \x01(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachines.VMDiskSecurityProfile\x12\x1c\n\x14storage_account_type\x18\x04 \x01(\t\"\xa8\x01\n\x15VMDiskSecurityProfile\x12m\n\x13\x64isk_encryption_set\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_compute_virtualmachines.DiskEncryptionSetParameters\x12 \n\x18security_encryption_type\x18\x02 \x01(\t\")\n\x1b\x44iskEncryptionSetParameters\x12\n\n\x02id\x18\x01 \x01(\t\"\x1e\n\x0fVirtualHardDisk\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\x9e\x01\n\x0fSecurityProfile\x12\x1a\n\x12\x65ncryption_at_host\x18\x01 \x01(\x08\x12\x15\n\rsecurity_type\x18\x02 \x01(\t\x12X\n\ruefi_settings\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_compute_virtualmachines.UefiSettings\"B\n\x0cUefiSettings\x12\x1b\n\x13secure_boot_enabled\x18\x01 \x01(\x08\x12\x15\n\rv_tpm_enabled\x18\x02 \x01(\x08\"\x93\x01\n\x16ScheduledEventsProfile\x12y\n\x1eterminate_notification_profile\x18\x01 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachines.TerminateNotificationProfile\"J\n\x1cTerminateNotificationProfile\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x1a\n\x12not_before_timeout\x18\x02 \x01(\t\"\xdb\x03\n\tOSProfile\x12\x16\n\x0e\x61\x64min_password\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64min_username\x18\x02 \x01(\t\x12\"\n\x1a\x61llow_extension_operations\x18\x03 \x01(\x08\x12\x15\n\rcomputer_name\x18\x04 \x01(\t\x12\x13\n\x0b\x63ustom_data\x18\x05 \x01(\t\x12\x64\n\x13linux_configuration\x18\x06 \x01(\x0b\x32G.oak9.tython.azure.microsoft_compute_virtualmachines.LinuxConfiguration\x12&\n\x1erequire_guest_provision_signal\x18\x07 \x01(\x08\x12V\n\x07secrets\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachines.VaultSecretGroup\x12h\n\x15windows_configuration\x18\t \x01(\x0b\x32I.oak9.tython.azure.microsoft_compute_virtualmachines.WindowsConfiguration\"\x93\x03\n\x14WindowsConfiguration\x12s\n\x1b\x61\x64\x64itional_unattend_content\x18\x01 \x03(\x0b\x32N.oak9.tython.azure.microsoft_compute_virtualmachines.AdditionalUnattendContent\x12 \n\x18\x65nable_automatic_updates\x18\x02 \x01(\x08\x12Z\n\x0epatch_settings\x18\x03 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_compute_virtualmachines.PatchSettings\x12\x1b\n\x13provision_v_m_agent\x18\x04 \x01(\x08\x12\x11\n\ttime_zone\x18\x05 \x01(\t\x12X\n\x07win_r_m\x18\x06 \x01(\x0b\x32G.oak9.tython.azure.microsoft_compute_virtualmachines.WinRMConfiguration\"k\n\x12WinRMConfiguration\x12U\n\tlisteners\x18\x01 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_compute_virtualmachines.WinRMListener\":\n\rWinRMListener\x12\x17\n\x0f\x63\x65rtificate_url\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\"X\n\rPatchSettings\x12\x17\n\x0f\x61ssessment_mode\x18\x01 \x01(\t\x12\x1a\n\x12\x65nable_hotpatching\x18\x02 \x01(\x08\x12\x12\n\npatch_mode\x18\x03 \x01(\t\"m\n\x19\x41\x64\x64itionalUnattendContent\x12\x16\n\x0e\x63omponent_name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tpass_name\x18\x03 \x01(\t\x12\x14\n\x0csetting_name\x18\x04 \x01(\t\"\x8b\x01\n\x10VaultSecretGroup\x12\x14\n\x0csource_vault\x18\x01 \x01(\t\x12\x61\n\x12vault_certificates\x18\x02 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachines.VaultCertificate\"F\n\x10VaultCertificate\x12\x19\n\x11\x63\x65rtificate_store\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_url\x18\x02 \x01(\t\"\x8f\x02\n\x12LinuxConfiguration\x12\'\n\x1f\x64isable_password_authentication\x18\x01 \x01(\x08\x12_\n\x0epatch_settings\x18\x02 \x01(\x0b\x32G.oak9.tython.azure.microsoft_compute_virtualmachines.LinuxPatchSettings\x12\x1b\n\x13provision_v_m_agent\x18\x03 \x01(\x08\x12R\n\x03ssh\x18\x04 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachines.SshConfiguration\"j\n\x10SshConfiguration\x12V\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_compute_virtualmachines.SshPublicKey\".\n\x0cSshPublicKey\x12\x10\n\x08key_data\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x12LinuxPatchSettings\x12\x17\n\x0f\x61ssessment_mode\x18\x01 \x01(\t\x12\x12\n\npatch_mode\x18\x02 \x01(\t\"\xa6\x02\n\x0eNetworkProfile\x12\x1b\n\x13network_api_version\x18\x01 \x01(\t\x12\x8a\x01\n network_interface_configurations\x18\x02 \x03(\x0b\x32`.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineNetworkInterfaceConfiguration\x12j\n\x12network_interfaces\x18\x03 \x03(\x0b\x32N.oak9.tython.azure.microsoft_compute_virtualmachines.NetworkInterfaceReference\"O\n\x19NetworkInterfaceReference\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"\xfc\x03\n+VirtualMachineNetworkInterfaceConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x81\x01\n\x0c\x64ns_settings\x18\x03 \x01(\x0b\x32k.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineNetworkInterfaceDnsSettingsConfiguration\x12\x1a\n\x12\x64scp_configuration\x18\x04 \x01(\t\x12%\n\x1d\x65nable_accelerated_networking\x18\x05 \x01(\x08\x12\x13\n\x0b\x65nable_fpga\x18\x06 \x01(\x08\x12\x1c\n\x14\x65nable_ip_forwarding\x18\x07 \x01(\x08\x12}\n\x11ip_configurations\x18\x08 \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineNetworkInterfaceIPConfiguration\x12\x1e\n\x16network_security_group\x18\t \x01(\t\x12\x0f\n\x07primary\x18\n \x01(\x08\"\x92\x03\n-VirtualMachineNetworkInterfaceIPConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n)application_gateway_backend_address_pools\x18\x02 \x03(\t\x12#\n\x1b\x61pplication_security_groups\x18\x03 \x03(\t\x12+\n#load_balancer_backend_address_pools\x18\x04 \x03(\t\x12\x0f\n\x07primary\x18\x05 \x01(\x08\x12\"\n\x1aprivate_ip_address_version\x18\x06 \x01(\t\x12\x88\x01\n\x1fpublic_ip_address_configuration\x18\x07 \x01(\x0b\x32_.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinePublicIPAddressConfiguration\x12\x0e\n\x06subnet\x18\x08 \x01(\t\"\x88\x04\n*VirtualMachinePublicIPAddressConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x80\x01\n\x0c\x64ns_settings\x18\x03 \x01(\x0b\x32j.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachinePublicIPAddressDnsSettingsConfiguration\x12\x1f\n\x17idle_timeout_in_minutes\x18\x04 \x01(\x05\x12Y\n\x07ip_tags\x18\x05 \x03(\x0b\x32H.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineIpTag\x12!\n\x19public_ip_address_version\x18\x06 \x01(\t\x12#\n\x1bpublic_ip_allocation_method\x18\x07 \x01(\t\x12\x18\n\x10public_ip_prefix\x18\x08 \x01(\t\x12T\n\x03sku\x18\t \x01(\x0b\x32G.oak9.tython.azure.microsoft_compute_virtualmachines.PublicIPAddressSku\"0\n\x12PublicIPAddressSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"7\n\x13VirtualMachineIpTag\x12\x13\n\x0bip_tag_type\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"R\n5VirtualMachinePublicIPAddressDnsSettingsConfiguration\x12\x19\n\x11\x64omain_name_label\x18\x01 \x01(\t\"M\n6VirtualMachineNetworkInterfaceDnsSettingsConfiguration\x12\x13\n\x0b\x64ns_servers\x18\x01 \x03(\t\"\x85\x01\n\x0fHardwareProfile\x12\x0f\n\x07vm_size\x18\x01 \x01(\t\x12\x61\n\x12vm_size_properties\x18\x02 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachines.VMSizeProperties\"E\n\x10VMSizeProperties\x12\x18\n\x10v_cpus_available\x18\x01 \x01(\x05\x12\x17\n\x0fv_cpus_per_core\x18\x02 \x01(\x05\"t\n\x12\x44iagnosticsProfile\x12^\n\x10\x62oot_diagnostics\x18\x01 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_compute_virtualmachines.BootDiagnostics\"7\n\x0f\x42ootDiagnostics\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0bstorage_uri\x18\x02 \x01(\t\"@\n\x1a\x43\x61pacityReservationProfile\x12\"\n\x1a\x63\x61pacity_reservation_group\x18\x01 \x01(\t\"#\n\x0e\x42illingProfile\x12\x11\n\tmax_price\x18\x01 \x01(\x01\"}\n\x12\x41pplicationProfile\x12g\n\x14gallery_applications\x18\x01 \x03(\x0b\x32I.oak9.tython.azure.microsoft_compute_virtualmachines.VMGalleryApplication\"r\n\x14VMGalleryApplication\x12\x1f\n\x17\x63onfiguration_reference\x18\x01 \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x1c\n\x14package_reference_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x01(\t\"P\n\x16\x41\x64\x64itionalCapabilities\x12\x1b\n\x13hibernation_enabled\x18\x01 \x01(\x08\x12\x19\n\x11ultra_ssd_enabled\x18\x02 \x01(\x08\"P\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07product\x18\x02 \x01(\t\x12\x16\n\x0epromotion_code\x18\x03 \x01(\t\x12\x11\n\tpublisher\x18\x04 \x01(\t\"\xf1\x01\n\x16VirtualMachineIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x89\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32g.oak9.tython.azure.microsoft_compute_virtualmachines.VirtualMachineIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_compute_virtualmachines_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VIRTUALMACHINESEXTENSIONS_PROPERTIESENTRY._options = None
  _VIRTUALMACHINESEXTENSIONS_PROPERTIESENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESEXTENSIONS_TAGSENTRY._options = None
  _VIRTUALMACHINESEXTENSIONS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._options = None
  _VIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINES_TAGSENTRY._options = None
  _VIRTUALMACHINES_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _VIRTUALMACHINEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESEXTENSIONS._serialized_start=130
  _VIRTUALMACHINESEXTENSIONS._serialized_end=562
  _VIRTUALMACHINESEXTENSIONS_PROPERTIESENTRY._serialized_start=468
  _VIRTUALMACHINESEXTENSIONS_PROPERTIESENTRY._serialized_end=517
  _VIRTUALMACHINESEXTENSIONS_TAGSENTRY._serialized_start=519
  _VIRTUALMACHINESEXTENSIONS_TAGSENTRY._serialized_end=562
  _AVAILABILITYSET._serialized_start=564
  _AVAILABILITYSET._serialized_end=593
  _MICROSOFT_COMPUTE_VIRTUALMACHINES._serialized_start=596
  _MICROSOFT_COMPUTE_VIRTUALMACHINES._serialized_end=727
  _VIRTUALMACHINESRUNCOMMANDS._serialized_start=730
  _VIRTUALMACHINESRUNCOMMANDS._serialized_end=1460
  _VIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._serialized_start=519
  _VIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._serialized_end=562
  _VIRTUALMACHINERUNCOMMANDSCRIPTSOURCE._serialized_start=1462
  _VIRTUALMACHINERUNCOMMANDSCRIPTSOURCE._serialized_end=1556
  _RUNCOMMANDINPUTPARAMETER._serialized_start=1558
  _RUNCOMMANDINPUTPARAMETER._serialized_end=1613
  _VIRTUALMACHINES._serialized_start=1616
  _VIRTUALMACHINES._serialized_end=3820
  _VIRTUALMACHINES_TAGSENTRY._serialized_start=519
  _VIRTUALMACHINES_TAGSENTRY._serialized_end=562
  _STORAGEPROFILE._serialized_start=3823
  _STORAGEPROFILE._serialized_end=4094
  _OSDISK._serialized_start=4097
  _OSDISK._serialized_end=4727
  _DISKENCRYPTIONSETTINGS._serialized_start=4730
  _DISKENCRYPTIONSETTINGS._serialized_end=4981
  _KEYVAULTKEYREFERENCE._serialized_start=4983
  _KEYVAULTKEYREFERENCE._serialized_end=5044
  _KEYVAULTSECRETREFERENCE._serialized_start=5046
  _KEYVAULTSECRETREFERENCE._serialized_end=5113
  _DIFFDISKSETTINGS._serialized_start=5115
  _DIFFDISKSETTINGS._serialized_end=5168
  _IMAGEREFERENCE._serialized_start=5171
  _IMAGEREFERENCE._serialized_end=5332
  _DATADISK._serialized_start=5335
  _DATADISK._serialized_end=5805
  _MANAGEDDISKPARAMETERS._serialized_start=5808
  _MANAGEDDISKPARAMETERS._serialized_end=6086
  _VMDISKSECURITYPROFILE._serialized_start=6089
  _VMDISKSECURITYPROFILE._serialized_end=6257
  _DISKENCRYPTIONSETPARAMETERS._serialized_start=6259
  _DISKENCRYPTIONSETPARAMETERS._serialized_end=6300
  _VIRTUALHARDDISK._serialized_start=6302
  _VIRTUALHARDDISK._serialized_end=6332
  _SECURITYPROFILE._serialized_start=6335
  _SECURITYPROFILE._serialized_end=6493
  _UEFISETTINGS._serialized_start=6495
  _UEFISETTINGS._serialized_end=6561
  _SCHEDULEDEVENTSPROFILE._serialized_start=6564
  _SCHEDULEDEVENTSPROFILE._serialized_end=6711
  _TERMINATENOTIFICATIONPROFILE._serialized_start=6713
  _TERMINATENOTIFICATIONPROFILE._serialized_end=6787
  _OSPROFILE._serialized_start=6790
  _OSPROFILE._serialized_end=7265
  _WINDOWSCONFIGURATION._serialized_start=7268
  _WINDOWSCONFIGURATION._serialized_end=7671
  _WINRMCONFIGURATION._serialized_start=7673
  _WINRMCONFIGURATION._serialized_end=7780
  _WINRMLISTENER._serialized_start=7782
  _WINRMLISTENER._serialized_end=7840
  _PATCHSETTINGS._serialized_start=7842
  _PATCHSETTINGS._serialized_end=7930
  _ADDITIONALUNATTENDCONTENT._serialized_start=7932
  _ADDITIONALUNATTENDCONTENT._serialized_end=8041
  _VAULTSECRETGROUP._serialized_start=8044
  _VAULTSECRETGROUP._serialized_end=8183
  _VAULTCERTIFICATE._serialized_start=8185
  _VAULTCERTIFICATE._serialized_end=8255
  _LINUXCONFIGURATION._serialized_start=8258
  _LINUXCONFIGURATION._serialized_end=8529
  _SSHCONFIGURATION._serialized_start=8531
  _SSHCONFIGURATION._serialized_end=8637
  _SSHPUBLICKEY._serialized_start=8639
  _SSHPUBLICKEY._serialized_end=8685
  _LINUXPATCHSETTINGS._serialized_start=8687
  _LINUXPATCHSETTINGS._serialized_end=8752
  _NETWORKPROFILE._serialized_start=8755
  _NETWORKPROFILE._serialized_end=9049
  _NETWORKINTERFACEREFERENCE._serialized_start=9051
  _NETWORKINTERFACEREFERENCE._serialized_end=9130
  _VIRTUALMACHINENETWORKINTERFACECONFIGURATION._serialized_start=9133
  _VIRTUALMACHINENETWORKINTERFACECONFIGURATION._serialized_end=9641
  _VIRTUALMACHINENETWORKINTERFACEIPCONFIGURATION._serialized_start=9644
  _VIRTUALMACHINENETWORKINTERFACEIPCONFIGURATION._serialized_end=10046
  _VIRTUALMACHINEPUBLICIPADDRESSCONFIGURATION._serialized_start=10049
  _VIRTUALMACHINEPUBLICIPADDRESSCONFIGURATION._serialized_end=10569
  _PUBLICIPADDRESSSKU._serialized_start=10571
  _PUBLICIPADDRESSSKU._serialized_end=10619
  _VIRTUALMACHINEIPTAG._serialized_start=10621
  _VIRTUALMACHINEIPTAG._serialized_end=10676
  _VIRTUALMACHINEPUBLICIPADDRESSDNSSETTINGSCONFIGURATION._serialized_start=10678
  _VIRTUALMACHINEPUBLICIPADDRESSDNSSETTINGSCONFIGURATION._serialized_end=10760
  _VIRTUALMACHINENETWORKINTERFACEDNSSETTINGSCONFIGURATION._serialized_start=10762
  _VIRTUALMACHINENETWORKINTERFACEDNSSETTINGSCONFIGURATION._serialized_end=10839
  _HARDWAREPROFILE._serialized_start=10842
  _HARDWAREPROFILE._serialized_end=10975
  _VMSIZEPROPERTIES._serialized_start=10977
  _VMSIZEPROPERTIES._serialized_end=11046
  _DIAGNOSTICSPROFILE._serialized_start=11048
  _DIAGNOSTICSPROFILE._serialized_end=11164
  _BOOTDIAGNOSTICS._serialized_start=11166
  _BOOTDIAGNOSTICS._serialized_end=11221
  _CAPACITYRESERVATIONPROFILE._serialized_start=11223
  _CAPACITYRESERVATIONPROFILE._serialized_end=11287
  _BILLINGPROFILE._serialized_start=11289
  _BILLINGPROFILE._serialized_end=11324
  _APPLICATIONPROFILE._serialized_start=11326
  _APPLICATIONPROFILE._serialized_end=11451
  _VMGALLERYAPPLICATION._serialized_start=11453
  _VMGALLERYAPPLICATION._serialized_end=11567
  _ADDITIONALCAPABILITIES._serialized_start=11569
  _ADDITIONALCAPABILITIES._serialized_end=11649
  _PLAN._serialized_start=11651
  _PLAN._serialized_end=11731
  _VIRTUALMACHINEIDENTITY._serialized_start=11734
  _VIRTUALMACHINEIDENTITY._serialized_end=11975
  _VIRTUALMACHINEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=11914
  _VIRTUALMACHINEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=11975
  _EXTENDEDLOCATION._serialized_start=11977
  _EXTENDEDLOCATION._serialized_end=12023
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_applicationautoscaling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$aws/aws_applicationautoscaling.proto\x12&oak9.tython.aws.applicationautoscaling\x1a\x13shared/shared.proto\"\x89\x01\n\"ScalableTargetScalableTargetAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\"\x9b\x02\n\x1dScalableTargetScheduledAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12j\n\x16scalable_target_action\x18\x03 \x01(\x0b\x32J.oak9.tython.aws.applicationautoscaling.ScalableTargetScalableTargetAction\x12\x10\n\x08schedule\x18\x04 \x01(\t\x12\x1d\n\x15scheduled_action_name\x18\x05 \x01(\t\x12\x12\n\nstart_time\x18\x06 \x01(\t\"\xc9\x01\n\x1cScalableTargetSuspendedState\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1c\x64ynamic_scaling_in_suspended\x18\x02 \x01(\x08\x12%\n\x1d\x64ynamic_scaling_out_suspended\x18\x03 \x01(\x08\x12#\n\x1bscheduled_scaling_suspended\x18\x04 \x01(\x08\"\x94\x03\n\x0eScalableTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x1a\n\x12scalable_dimension\x18\x06 \x01(\t\x12`\n\x11scheduled_actions\x18\x07 \x03(\x0b\x32\x45.oak9.tython.aws.applicationautoscaling.ScalableTargetScheduledAction\x12\x19\n\x11service_namespace\x18\x08 \x01(\t\x12]\n\x0fsuspended_state\x18\t \x01(\x0b\x32\x44.oak9.tython.aws.applicationautoscaling.ScalableTargetSuspendedState\"\xb8\x01\n\x16\x41pplicationAutoScaling\x12O\n\x0fscalable_target\x18\x01 \x03(\x0b\x32\x36.oak9.tython.aws.applicationautoscaling.ScalableTarget\x12M\n\x0escaling_policy\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.applicationautoscaling.ScalingPolicy\"\xbc\x01\n\x1bScalingPolicyStepAdjustment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1bmetric_interval_lower_bound\x18\x02 \x01(\x01\x12#\n\x1bmetric_interval_upper_bound\x18\x03 \x01(\x01\x12\x1a\n\x12scaling_adjustment\x18\x04 \x01(\x05\"\xb3\x02\n+ScalingPolicyStepScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64justment_type\x18\x02 \x01(\t\x12\x10\n\x08\x63ooldown\x18\x03 \x01(\x05\x12\x1f\n\x17metric_aggregation_type\x18\x04 \x01(\t\x12 \n\x18min_adjustment_magnitude\x18\x05 \x01(\x05\x12]\n\x10step_adjustments\x18\x06 \x03(\x0b\x32\x43.oak9.tython.aws.applicationautoscaling.ScalingPolicyStepAdjustment\"t\n\x1cScalingPolicyMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x88\x02\n*ScalingPolicyCustomizedMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\ndimensions\x18\x02 \x03(\x0b\x32\x44.oak9.tython.aws.applicationautoscaling.ScalingPolicyMetricDimension\x12\x13\n\x0bmetric_name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x11\n\tstatistic\x18\x05 \x01(\t\x12\x0c\n\x04unit\x18\x06 \x01(\t\"\x9d\x01\n*ScalingPolicyPredefinedMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16predefined_metric_type\x18\x02 \x01(\t\x12\x16\n\x0eresource_label\x18\x03 \x01(\t\"\xd1\x03\n5ScalingPolicyTargetTrackingScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12{\n\x1f\x63ustomized_metric_specification\x18\x02 \x01(\x0b\x32R.oak9.tython.aws.applicationautoscaling.ScalingPolicyCustomizedMetricSpecification\x12\x18\n\x10\x64isable_scale_in\x18\x03 \x01(\x08\x12{\n\x1fpredefined_metric_specification\x18\x04 \x01(\x0b\x32R.oak9.tython.aws.applicationautoscaling.ScalingPolicyPredefinedMetricSpecification\x12\x19\n\x11scale_in_cooldown\x18\x05 \x01(\x05\x12\x1a\n\x12scale_out_cooldown\x18\x06 \x01(\x05\x12\x14\n\x0ctarget_value\x18\x07 \x01(\x01\"\xef\x03\n\rScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_type\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x1a\n\x12scalable_dimension\x18\x05 \x01(\t\x12\x19\n\x11scaling_target_id\x18\x06 \x01(\t\x12\x19\n\x11service_namespace\x18\x07 \x01(\t\x12~\n!step_scaling_policy_configuration\x18\x08 \x01(\x0b\x32S.oak9.tython.aws.applicationautoscaling.ScalingPolicyStepScalingPolicyConfiguration\x12\x93\x01\n,target_tracking_scaling_policy_configuration\x18\t \x01(\x0b\x32].oak9.tython.aws.applicationautoscaling.ScalingPolicyTargetTrackingScalingPolicyConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_applicationautoscaling_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCALABLETARGETSCALABLETARGETACTION._serialized_start=102
  _SCALABLETARGETSCALABLETARGETACTION._serialized_end=239
  _SCALABLETARGETSCHEDULEDACTION._serialized_start=242
  _SCALABLETARGETSCHEDULEDACTION._serialized_end=525
  _SCALABLETARGETSUSPENDEDSTATE._serialized_start=528
  _SCALABLETARGETSUSPENDEDSTATE._serialized_end=729
  _SCALABLETARGET._serialized_start=732
  _SCALABLETARGET._serialized_end=1136
  _APPLICATIONAUTOSCALING._serialized_start=1139
  _APPLICATIONAUTOSCALING._serialized_end=1323
  _SCALINGPOLICYSTEPADJUSTMENT._serialized_start=1326
  _SCALINGPOLICYSTEPADJUSTMENT._serialized_end=1514
  _SCALINGPOLICYSTEPSCALINGPOLICYCONFIGURATION._serialized_start=1517
  _SCALINGPOLICYSTEPSCALINGPOLICYCONFIGURATION._serialized_end=1824
  _SCALINGPOLICYMETRICDIMENSION._serialized_start=1826
  _SCALINGPOLICYMETRICDIMENSION._serialized_end=1942
  _SCALINGPOLICYCUSTOMIZEDMETRICSPECIFICATION._serialized_start=1945
  _SCALINGPOLICYCUSTOMIZEDMETRICSPECIFICATION._serialized_end=2209
  _SCALINGPOLICYPREDEFINEDMETRICSPECIFICATION._serialized_start=2212
  _SCALINGPOLICYPREDEFINEDMETRICSPECIFICATION._serialized_end=2369
  _SCALINGPOLICYTARGETTRACKINGSCALINGPOLICYCONFIGURATION._serialized_start=2372
  _SCALINGPOLICYTARGETTRACKINGSCALINGPOLICYCONFIGURATION._serialized_end=2837
  _SCALINGPOLICY._serialized_start=2840
  _SCALINGPOLICY._serialized_end=3335
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_iotcentral.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&azure/azure_microsoft_iotcentral.proto\x12&oak9.tython.azure.microsoft_iotcentral\x1a\x13shared/shared.proto\"Y\n\x14Microsoft_IotCentral\x12\x41\n\x08iot_apps\x18\x01 \x03(\x0b\x32/.oak9.tython.azure.microsoft_iotcentral.IotApps\"\xbc\x03\n\x07IotApps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x08identity\x18\x02 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_iotcentral.SystemAssignedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x11\n\tsubdomain\x18\x07 \x01(\t\x12\x10\n\x08template\x18\x08 \x01(\t\x12?\n\x03sku\x18\t \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_iotcentral.AppSkuInfo\x12G\n\x04tags\x18\n \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_iotcentral.IotApps.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\nAppSkuInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\"-\n\x1dSystemAssignedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_iotcentral_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IOTAPPS_TAGSENTRY._options = None
  _IOTAPPS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_IOTCENTRAL._serialized_start=103
  _MICROSOFT_IOTCENTRAL._serialized_end=192
  _IOTAPPS._serialized_start=195
  _IOTAPPS._serialized_end=639
  _IOTAPPS_TAGSENTRY._serialized_start=596
  _IOTAPPS_TAGSENTRY._serialized_end=639
  _APPSKUINFO._serialized_start=641
  _APPSKUINFO._serialized_end=667
  _SYSTEMASSIGNEDSERVICEIDENTITY._serialized_start=669
  _SYSTEMASSIGNEDSERVICEIDENTITY._serialized_end=714
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iotevents.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_iotevents.proto\x12\x19oak9.tython.aws.iotevents\x1a\x13shared/shared.proto\"k\n\x14\x44\x65tectorModelPayload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63ontent_expression\x18\x02 \x01(\t\"\xa7\x01\n\x16\x44\x65tectorModelIotEvents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ninput_name\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\xc3\x01\n\x15\x44\x65tectorModelFirehose\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65livery_stream_name\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\x12\x11\n\tseparator\x18\x04 \x01(\t\"\xad\x01\n\x1c\x44\x65tectorModelIotTopicPublish\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\xe1\x02\n\x15\x44\x65tectorModelDynamoDB\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x15\n\rpayload_field\x18\x03 \x01(\t\x12\x17\n\x0frange_key_field\x18\x04 \x01(\t\x12\x16\n\x0ehash_key_field\x18\x05 \x01(\t\x12\x17\n\x0frange_key_value\x18\x06 \x01(\t\x12\x16\n\x0erange_key_type\x18\x07 \x01(\t\x12\x15\n\rhash_key_type\x18\x08 \x01(\t\x12\x16\n\x0ehash_key_value\x18\t \x01(\t\x12@\n\x07payload\x18\n \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\x12\x11\n\toperation\x18\x0b \x01(\t\"\xa8\x01\n\x17\x44\x65tectorModelDynamoDBv2\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\xb6\x01\n!DetectorModelAssetPropertyVariant\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\t\x12\x15\n\rinteger_value\x18\x03 \x01(\t\x12\x15\n\rboolean_value\x18\x04 \x01(\t\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\x90\x01\n#DetectorModelAssetPropertyTimestamp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0ftime_in_seconds\x18\x02 \x01(\t\x12\x17\n\x0foffset_in_nanos\x18\x03 \x01(\t\"\x8b\x02\n\x1f\x44\x65tectorModelAssetPropertyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07quality\x18\x02 \x01(\t\x12K\n\x05value\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.iotevents.DetectorModelAssetPropertyVariant\x12Q\n\ttimestamp\x18\x04 \x01(\x0b\x32>.oak9.tython.aws.iotevents.DetectorModelAssetPropertyTimestamp\"\xf8\x01\n\x18\x44\x65tectorModelIotSiteWise\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\t\x12\x16\n\x0eproperty_alias\x18\x03 \x01(\t\x12R\n\x0eproperty_value\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.iotevents.DetectorModelAssetPropertyValue\x12\x10\n\x08\x61sset_id\x18\x05 \x01(\t\x12\x13\n\x0bproperty_id\x18\x06 \x01(\t\"f\n\x17\x44\x65tectorModelResetTimer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntimer_name\x18\x02 \x01(\t\"\xb4\x01\n\x10\x44\x65tectorModelSqs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nuse_base64\x18\x02 \x01(\x08\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\x12\x11\n\tqueue_url\x18\x04 \x01(\t\"\xa1\x01\n\x10\x44\x65tectorModelSns\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntarget_arn\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\x92\x01\n\x15\x44\x65tectorModelSetTimer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07seconds\x18\x02 \x01(\x05\x12\x12\n\ntimer_name\x18\x03 \x01(\t\x12\x1b\n\x13\x64uration_expression\x18\x04 \x01(\t\"f\n\x17\x44\x65tectorModelClearTimer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntimer_name\x18\x02 \x01(\t\"\xa6\x01\n\x13\x44\x65tectorModelLambda\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"y\n\x18\x44\x65tectorModelSetVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rvariable_name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xdd\x07\n\x13\x44\x65tectorModelAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\niot_events\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.iotevents.DetectorModelIotEvents\x12\x42\n\x08\x66irehose\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.iotevents.DetectorModelFirehose\x12R\n\x11iot_topic_publish\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.iotevents.DetectorModelIotTopicPublish\x12\x43\n\tdynamo_db\x18\x05 \x01(\x0b\x32\x30.oak9.tython.aws.iotevents.DetectorModelDynamoDB\x12G\n\x0b\x64ynamo_dbv2\x18\x06 \x01(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModelDynamoDBv2\x12J\n\riot_site_wise\x18\x07 \x01(\x0b\x32\x33.oak9.tython.aws.iotevents.DetectorModelIotSiteWise\x12G\n\x0breset_timer\x18\x08 \x01(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModelResetTimer\x12\x38\n\x03sqs\x18\t \x01(\x0b\x32+.oak9.tython.aws.iotevents.DetectorModelSqs\x12\x38\n\x03sns\x18\n \x01(\x0b\x32+.oak9.tython.aws.iotevents.DetectorModelSns\x12\x43\n\tset_timer\x18\x0b \x01(\x0b\x32\x30.oak9.tython.aws.iotevents.DetectorModelSetTimer\x12G\n\x0b\x63lear_timer\x18\x0c \x01(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModelClearTimer\x12>\n\x06lambda\x18\r \x01(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelLambda\x12I\n\x0cset_variable\x18\x0e \x01(\x0b\x32\x33.oak9.tython.aws.iotevents.DetectorModelSetVariable\"\xb5\x01\n\x12\x44\x65tectorModelEvent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcondition\x18\x02 \x01(\t\x12?\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelAction\x12\x12\n\nevent_name\x18\x04 \x01(\t\"\xd3\x01\n\x1c\x44\x65tectorModelTransitionEvent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcondition\x18\x02 \x01(\t\x12?\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelAction\x12\x12\n\nnext_state\x18\x04 \x01(\t\x12\x12\n\nevent_name\x18\x05 \x01(\t\"\xe2\x01\n\x14\x44\x65tectorModelOnInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x65vents\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelEvent\x12R\n\x11transition_events\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.iotevents.DetectorModelTransitionEvent\"\x8d\x01\n\x13\x44\x65tectorModelOnExit\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x65vents\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelEvent\"\x8e\x01\n\x14\x44\x65tectorModelOnEnter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x65vents\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelEvent\"\xa8\x02\n\x12\x44\x65tectorModelState\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x08on_input\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelOnInput\x12?\n\x07on_exit\x18\x03 \x01(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelOnExit\x12\x12\n\nstate_name\x18\x04 \x01(\t\x12\x41\n\x08on_enter\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelOnEnter\"\xba\x01\n$DetectorModelDetectorModelDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06states\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelState\x12\x1a\n\x12initial_state_name\x18\x03 \x01(\t\"\x96\x03\n\rDetectorModel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x19\x64\x65tector_model_definition\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.iotevents.DetectorModelDetectorModelDefinition\x12\x19\n\x11\x65valuation_method\x18\x03 \x01(\t\x12\x1b\n\x13\x64\x65tector_model_name\x18\x04 \x01(\t\x12\"\n\x1a\x64\x65tector_model_description\x18\x05 \x01(\t\x12\x0b\n\x03key\x18\x06 \x01(\t\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12@\n\x04tags\x18\x08 \x03(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModel.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\tIoTEvents\x12@\n\x0e\x64\x65tector_model\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.iotevents.DetectorModel\x12/\n\x05input\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.iotevents.Input\"\\\n\x0eInputAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tjson_path\x18\x02 \x01(\t\"\x8e\x01\n\x14InputInputDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\nattributes\x18\x02 \x03(\x0b\x32).oak9.tython.aws.iotevents.InputAttribute\"\xa1\x02\n\x05Input\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x10input_definition\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.iotevents.InputInputDefinition\x12\x12\n\ninput_name\x18\x03 \x01(\t\x12\x19\n\x11input_description\x18\x04 \x01(\t\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.iotevents.Input.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iotevents_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTORMODEL_TAGSENTRY._options = None
  _DETECTORMODEL_TAGSENTRY._serialized_options = b'8\001'
  _INPUT_TAGSENTRY._options = None
  _INPUT_TAGSENTRY._serialized_options = b'8\001'
  _DETECTORMODELPAYLOAD._serialized_start=75
  _DETECTORMODELPAYLOAD._serialized_end=182
  _DETECTORMODELIOTEVENTS._serialized_start=185
  _DETECTORMODELIOTEVENTS._serialized_end=352
  _DETECTORMODELFIREHOSE._serialized_start=355
  _DETECTORMODELFIREHOSE._serialized_end=550
  _DETECTORMODELIOTTOPICPUBLISH._serialized_start=553
  _DETECTORMODELIOTTOPICPUBLISH._serialized_end=726
  _DETECTORMODELDYNAMODB._serialized_start=729
  _DETECTORMODELDYNAMODB._serialized_end=1082
  _DETECTORMODELDYNAMODBV2._serialized_start=1085
  _DETECTORMODELDYNAMODBV2._serialized_end=1253
  _DETECTORMODELASSETPROPERTYVARIANT._serialized_start=1256
  _DETECTORMODELASSETPROPERTYVARIANT._serialized_end=1438
  _DETECTORMODELASSETPROPERTYTIMESTAMP._serialized_start=1441
  _DETECTORMODELASSETPROPERTYTIMESTAMP._serialized_end=1585
  _DETECTORMODELASSETPROPERTYVALUE._serialized_start=1588
  _DETECTORMODELASSETPROPERTYVALUE._serialized_end=1855
  _DETECTORMODELIOTSITEWISE._serialized_start=1858
  _DETECTORMODELIOTSITEWISE._serialized_end=2106
  _DETECTORMODELRESETTIMER._serialized_start=2108
  _DETECTORMODELRESETTIMER._serialized_end=2210
  _DETECTORMODELSQS._serialized_start=2213
  _DETECTORMODELSQS._serialized_end=2393
  _DETECTORMODELSNS._serialized_start=2396
  _DETECTORMODELSNS._serialized_end=2557
  _DETECTORMODELSETTIMER._serialized_start=2560
  _DETECTORMODELSETTIMER._serialized_end=2706
  _DETECTORMODELCLEARTIMER._serialized_start=2708
  _DETECTORMODELCLEARTIMER._serialized_end=2810
  _DETECTORMODELLAMBDA._serialized_start=2813
  _DETECTORMODELLAMBDA._serialized_end=2979
  _DETECTORMODELSETVARIABLE._serialized_start=2981
  _DETECTORMODELSETVARIABLE._serialized_end=3102
  _DETECTORMODELACTION._serialized_start=3105
  _DETECTORMODELACTION._serialized_end=4094
  _DETECTORMODELEVENT._serialized_start=4097
  _DETECTORMODELEVENT._serialized_end=4278
  _DETECTORMODELTRANSITIONEVENT._serialized_start=4281
  _DETECTORMODELTRANSITIONEVENT._serialized_end=4492
  _DETECTORMODELONINPUT._serialized_start=4495
  _DETECTORMODELONINPUT._serialized_end=4721
  _DETECTORMODELONEXIT._serialized_start=4724
  _DETECTORMODELONEXIT._serialized_end=4865
  _DETECTORMODELONENTER._serialized_start=4868
  _DETECTORMODELONENTER._serialized_end=5010
  _DETECTORMODELSTATE._serialized_start=5013
  _DETECTORMODELSTATE._serialized_end=5309
  _DETECTORMODELDETECTORMODELDEFINITION._serialized_start=5312
  _DETECTORMODELDETECTORMODELDEFINITION._serialized_end=5498
  _DETECTORMODEL._serialized_start=5501
  _DETECTORMODEL._serialized_end=5907
  _DETECTORMODEL_TAGSENTRY._serialized_start=5864
  _DETECTORMODEL_TAGSENTRY._serialized_end=5907
  _IOTEVENTS._serialized_start=5909
  _IOTEVENTS._serialized_end=6035
  _INPUTATTRIBUTE._serialized_start=6037
  _INPUTATTRIBUTE._serialized_end=6129
  _INPUTINPUTDEFINITION._serialized_start=6132
  _INPUTINPUTDEFINITION._serialized_end=6274
  _INPUT._serialized_start=6277
  _INPUT._serialized_end=6566
  _INPUT_TAGSENTRY._serialized_start=5864
  _INPUT_TAGSENTRY._serialized_end=5907
# @@protoc_insertion_point(module_scope)
